@@ -7,28 +7,28 @@ class TextRNN(nn.Module):
         super(TextRNN, self).__init__()
         self.config = config
         self.evaluate_model = evaluate_model
-        
+
         # Embedding Layer
         self.embeddings = nn.Embedding(vocab_size, self.config.embed_size)
         self.embeddings.weight = nn.Parameter(word_embeddings, requires_grad=False)
-        
+
         self.lstm = nn.LSTM(input_size = self.config.embed_size,
                             hidden_size = self.config.hidden_size,
                             num_layers = self.config.hidden_layers,
                             dropout = self.config.dropout_keep,
                             bidirectional = self.config.bidirectional)
-        
+
         self.dropout = nn.Dropout(self.config.dropout_keep)
-        
+
         # Fully-Connected Layer
         self.fc = nn.Linear(
             self.config.hidden_size * self.config.hidden_layers * (1+self.config.bidirectional),
             self.config.output_size
         )
-        
+
         # Softmax non-linearity
         self.softmax = nn.LogSoftmax()
-        
+
     def forward(self, x):
         # x.shape = (max_sen_len, batch_size)
         embedded_sent = self.embeddings(x)
@@ -36,31 +36,31 @@ class TextRNN(nn.Module):
 
         lstm_out, (h_n,c_n) = self.lstm(embedded_sent)
         final_feature_map = self.dropout(h_n) # shape=(num_layers * num_directions, 64, hidden_size)
-        
+
         # Convert input to (64, hidden_size * hidden_layers * num_directions) for linear layer
         final_feature_map = torch.cat([final_feature_map[i,:,:] for i in range(final_feature_map.shape[0])], dim=1)
         final_out = self.fc(final_feature_map)
         return self.softmax(final_out)
-    
+
     def add_optimizer(self, optimizer):
         self.optimizer = optimizer
-        
+
     def add_loss_op(self, loss_op):
         self.loss_op = loss_op
-    
+
     def reduce_lr(self):
         for g in self.optimizer.param_groups:
             g['lr'] = g['lr'] / 2
-                
-    def run_epoch(self, train_iterator, val_iterator, epoch):
+
+    def run_epoch(self, train_iterator, val_iterator, epoch, classes, pos_label):
         train_losses = []
         val_accuracies = []
         losses = []
-        
+
         # Reduce learning rate as number of epochs increase
         if (epoch == int(self.config.max_epochs/3)) or (epoch == int(2*self.config.max_epochs/3)):
             self.reduce_lr()
-            
+
         for i, batch in enumerate(train_iterator):
             self.optimizer.zero_grad()
             if torch.cuda.is_available():
@@ -74,13 +74,13 @@ class TextRNN(nn.Module):
             loss.backward()
             losses.append(loss.data.cpu().numpy())
             self.optimizer.step()
-    
+
             if i % 100 == 0:
                 avg_train_loss = np.mean(losses)
                 train_losses.append(avg_train_loss)
                 losses = []
                 # Evalute Accuracy on validation set
-                report = self.evaluate_model(self, val_iterator)
+                report = self.evaluate_model(self, val_iterator, classes, pos_label)
                 report.training_loss = avg_train_loss
                 val_accuracies.append(report.accuracy)
                 self.train()
